allib.feature\_extraction package
=================================

Submodules
----------

allib.feature\_extraction.base module
-------------------------------------

.. automodule:: allib.feature_extraction.base
   :members:
   :undoc-members:
   :show-inheritance:

allib.feature\_extraction.catalog module
----------------------------------------

.. automodule:: allib.feature_extraction.catalog
   :members:
   :undoc-members:
   :show-inheritance:

allib.feature\_extraction.contextinstance module
------------------------------------------------

.. automodule:: allib.feature_extraction.contextinstance
   :members:
   :undoc-members:
   :show-inheritance:

allib.feature\_extraction.doc2vec module
----------------------------------------

.. automodule:: allib.feature_extraction.doc2vec
   :members:
   :undoc-members:
   :show-inheritance:

allib.feature\_extraction.factory module
----------------------------------------

.. automodule:: allib.feature_extraction.factory
   :members:
   :undoc-members:
   :show-inheritance:

allib.feature\_extraction.textinstance module
---------------------------------------------

.. automodule:: allib.feature_extraction.textinstance
   :members:
   :undoc-members:
   :show-inheritance:

allib.feature\_extraction.textsklearn module
--------------------------------------------

.. automodule:: allib.feature_extraction.textsklearn
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: allib.feature_extraction
   :members:
   :undoc-members:
   :show-inheritance:
